==> mio-client-1.0.4.tar.gz: mio-client-1.0.4/src/mio/dox.py <==
# Copyright 2022 Datum Technology Corporation
# SPDX-License-Identifier: Apache-2.0 WITH SHL-2.1
########################################################################################################################

from mio import discovery
from mio import cfg

import subprocess


def gen_doxygen(ip_name):
    if ip_name not in discovery.ip_paths:
        sys.exit("Failed to find IP '" + ip_name + "'.  Exiting.")
    ip_path = discovery.ip_paths[ip_name]
    ip_metadata = discovery.ip_metadata[ip_name]
    ip_src_path = ip_path + "/" + ip_metadata['structure']['src-path']
    ip_bin_path = ip_path + "/" + ip_metadata['structure']['scripts-path']
    args  = " PROJECT_NAME='" + ip_metadata['ip']['full-name'] + "'"
    args += " PROJECT_BRIEF='" + ip_metadata['ip']['full-name'] + "'"
    args += " IP_NAME='" + ip_metadata['ip']['name'] + "'"
    args += " PROJECT_NUMBER='" + ip_metadata['ip']['name'] + "'"
    args += " EXAMPLE_PATH=" + ip_path + "/" + ip_metadata['structure']['examples-path']
    args += " OUTPUT_DIRECTORY=" + ip_path + "/" + ip_metadata['structure']['docs-path'] + "/dox_out"
    args += " SRC_PATH=" + ip_src_path + " MIO_HOME=" + cfg.mio_data_src_dir + " IP_NAME=" + ip_name
    
    args += " DOCS_PATH+=" + ip_path + "/" + ip_metadata['structure']['docs-path']
    #args += " IMAGE_PATH=" + ip_path + "/" + ip_metadata['structure']['docs-path']
    #args += " INPUT+="     + ip_path + "/" + ip_metadata['structure']['docs-path']
    #for input_dir in ip_metadata['hdl-src']['directories']:
    #    if input_dir != "." and input_dir != "":
    #        args += " INPUT+=" + ip_src_path + "/" + input_dir
    #    else:
    #        args += " INPUT+=" + ip_src_path
    print(args)
    subprocess.call(args + " doxygen " + cfg.mio_data_src_dir + "/doxygen.cfg", shell=True)

==> mio-client-1.4.2.tar.gz: mio-client-1.4.2/src/mio/dox.py <==
# Copyright 2022 Datum Technology Corporation
# SPDX-License-Identifier: Apache-2.0 WITH SHL-2.1
########################################################################################################################

from mio import common
from mio import cache
from mio import cfg
from mio import eal

import subprocess


def gen_doxygen():
    ip_name = cfg.target_ip_name
    ip_path = cfg.target_ip['path']
    ip_metadata = cfg.target_ip['data']
    ip_src_path = ip_path + "/" + ip_metadata['structure']['src-path']
    ip_bin_path = ip_path + "/" + ip_metadata['structure']['scripts-path']
    args  = " PROJECT_NAME='" + ip_metadata['ip']['full-name'] + "'"
    args += " PROJECT_BRIEF='" + ip_metadata['ip']['full-name'] + "'"
    args += " IP_NAME='" + ip_metadata['ip']['name'] + "'"
    args += " PROJECT_NUMBER='" + ip_metadata['ip']['name'] + "'"
    args += " EXAMPLE_PATH=" + ip_path + "/" + ip_metadata['structure']['examples-path']
    args += " OUTPUT_PATH=" + ip_path + "/" + ip_metadata['structure']['docs-path'] + "/dox_out"
    args += " SRC_PATH=" + ip_src_path + " MIO_HOME=" + cfg.mio_data_src_dir + " IP_NAME=" + ip_name
    
    args += " DOCS_PATH+=" + ip_path + "/" + ip_metadata['structure']['docs-path']
    #args += " IMAGE_PATH=" + ip_path + "/" + ip_metadata['structure']['docs-path']
    #args += " INPUT+="     + ip_path + "/" + ip_metadata['structure']['docs-path']
    #for input_dir in ip_metadata['hdl-src']['directories']:
    #    if input_dir != "." and input_dir != "":
    #        args += " INPUT+=" + ip_src_path + "/" + input_dir
    #    else:
    #        args += " INPUT+=" + ip_src_path
    common.info(f"Invoking Doxygen on IP '{cfg.target_ip_name}' ({ip_src_path})")
    eal.launch_eda_bin(args + " doxygen", [cfg.mio_data_src_dir + "/doxygen.private.cfg"], cfg.mio_data_dir)
    common.info("Done.  To view documentation: `firefox " + ip_path + "/" + ip_metadata['structure']['docs-path'] + "/dox_out/html/index.html &`")
